@@ -1735,17 +1735,19 @@ impl Lua {
 
                 match (*fut).as_mut().poll(&mut ctx) {
                     Poll::Pending => {
-                        check_stack(state, 6)?;
+                        check_stack(state, 1)?;
                         ffi::lua_pushboolean(state, 0);
-                        push_gc_userdata(state, AsyncPollPending)?;
-                        Ok(2)
+                        Ok(1)
                     }
                     Poll::Ready(results) => {
-                        let results = lua.create_sequence_from(results?)?;
-                        check_stack(state, 2)?;
+                        let results = results?;
+                        let nresults = results.len() as Integer;
+                        let results = lua.create_sequence_from(results)?;
+                        check_stack(state, 3)?;
                         ffi::lua_pushboolean(state, 1);
                         lua.push_value(Value::Table(results))?;
-                        Ok(2)
+                        lua.push_value(Value::Integer(nresults))?;
+                        Ok(3)
                     }
                 }
             })
@@ -1772,24 +1774,31 @@ impl Lua {
         env.set("yield", coroutine.get::<_, Function>("yield")?)?;
         env.set(
             "unpack",
-            self.create_function(|_, tbl: Table| {
+            self.create_function(|_, (tbl, len): (Table, Integer)| {
                 Ok(MultiValue::from_vec(
-                    tbl.sequence_values().collect::<Result<Vec<Value>>>()?,
+                    tbl.raw_sequence_values_by_len(Some(len))
+                        .collect::<Result<Vec<Value>>>()?,
                 ))
             })?,
         )?;
+        env.set("pending", unsafe {
+            let _sg = StackGuard::new(self.state);
+            check_stack(self.state, 5)?;
+            push_gc_userdata(self.state, AsyncPollPending)?;
+            self.pop_value()
+        })?;
 
         // We set `poll` variable in the env table to be able to destroy upvalues
         self.load(
             r#"
             poll = get_poll(...)
-            local poll, yield, unpack = poll, yield, unpack
+            local poll, pending, yield, unpack = poll, pending, yield, unpack
             while true do
-                ready, res = poll()
+                local ready, res, nres = poll()
                 if ready then
-                    return unpack(res)
+                    return unpack(res, nres)
                 end
-                yield(res)
+                yield(pending)
             end
             "#,
         )
